# pylint: disable=missing-function-docstring
# pylint: disable=missing-class-docstring
# pylint: disable=line-too-long
# pylint: disable=unused-wildcard-import
# pylint: disable=wildcard-import
# pylint: disable=unused-import
'''
    A module of utility methods used for generating random data or performing various
    actions randomly.

    ----------

    Meta
    ----------
    `author`: Colemen Atwood
    `created`: 06-03-2022 10:22:15
    `memberOf`: rand_utils
'''

# import random
# import hashlib
# import time
# import string
# from typing import Union
# from faker import Faker
# import facades.rand_utils_facade as rand

import utils.random_utils.rand_utils as util
import utils.random_utils.rand_generation as gen

from utils.random_utils.rand_utils import *
from utils.random_utils.rand_generation import *